[![Build Status](https://travis-ci.org/uw-it-cte/django-sws-emsaiu.svg?branch=master)](https://travis-ci.org/uw-it-cte/django-sws-emsaiu)
[![Coverage Status](https://coveralls.io/repos/github/uw-it-cte/django-sws-emsaiu/badge.svg?branch=master)](https://coveralls.io/github/uw-it-cte/django-sws-emsaiu?branch=master)

# django-sms-emsaiu
Export course schedules from SWS, for import to EMS.
